// Importing modules from D3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

//redering svg tag from html
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//Creating Line graph
const render = data => { 
// Assigning X axis data   
  const xValue = d => d.Year; 
  const xAxisLabel = 'Year';
// Assigning Y axis data 
  const yValue = d => d.Percentage;
  const yAxisLabel = 'Percentage';
  
  const margin = { top: 40, right: 20, bottom: 38, left: 130 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-20 - margin.bottom-30;
  
  //  Scale for X axis
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //round values out
  
//  Scale for Y axis  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

//center g in svg
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

  //Creating xaxis
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
 //Creating yaxis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  
  //Appending y axis label to svg element	
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 6)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //Appending x axis label to svg element  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// Drawing a line
//adding it to svg 
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  //Appending line graph to svg
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
};

// Loading CSV data from URI
csv('https://gist.githubusercontent.com/Tejucmandava/786a5c8a5efccce55f669ceacd2108fb/raw/bff84a188ebc006fb292902c0a30cb2a255519b3/usa%2520population.csv')
  .then(data => {
  //console.log(data)
    data.forEach(d => {
    	d.Percentage = +d.Percentage;
//Formatting to retrieve year from the date
      d.Year = new Date(d.Year);
    });

    render(data);
  });